precision highp float;
uniform sampler2D uTexture;
varying vec2 vTextureCoord;
varying vec4 vPosition;
uniform float uWidth;
uniform float uHeight;
uniform float uCircleWidth;
uniform float uCircleHeight;
uniform float uCircleRadius;
uniform float uAngle;
uniform float uRotation;
uniform mat4 uMatrix;
uniform mat4 uPreMatrix;
uniform mat4 uPostMatrix;



void main() {

        float pi = 3.141592653589793;
        float xi = vPosition.x/uWidth + 0.5;
        float yi = vPosition.y/uHeight + 0.5;
        float phi = pi * yi;

        float z = cos(phi);
        float ringradius = sin(phi);
        float theta = pi * 2.0 * (1.0 - xi);
        float x = ringradius * cos(theta);
        float y = ringradius * sin(theta);
        vec4 logoColor;
        vec4 pos = uMatrix * vec4(x,y,z,1.0);
        pos = uPreMatrix * pos;
        pos = uPostMatrix * pos;
        phi = atan(sqrt(pos.x * pos.x + pos.y * pos.y),pos.z);
        theta = atan(pos.y , pos.x);
        theta = theta + radians(uRotation);

    	float r = (pi - phi)/uAngle * uCircleRadius;
    	float u = r * cos(theta) + uCircleWidth/2.0;
    	float v = r * sin(theta) + uCircleHeight/2.0;
    	u /= uCircleWidth;
    	v /= uCircleHeight;
    	vec2 coord = vec2(u,v);
    	vec2 minVal = vec2(0.0,0.0);
    	vec2 maxVal = vec2(1.0,1.0);
    	vec2 minCoord = max(coord , minVal);
    	vec2 maxCoord = min(coord , maxVal);
    	coord = clamp(coord , minVal ,maxVal);
    	coord = vec2(1.0-coord.x , coord.y);
    	logoColor = texture2D(uTexture,coord);
        gl_FragColor = logoColor;

        if(any(equal(minVal , minCoord)) || any(equal(maxVal , maxCoord))){
            gl_FragColor.a = 0.0;
            gl_FragColor.rgb *= gl_FragColor.a;
        }
}