#extension GL_OES_EGL_image_external : enable 
precision highp float;

uniform samplerExternalOES uTexture;
varying vec2 vTextureCoord;
varying vec2 vTextureCoord2;
varying vec4 vPosition;
uniform mat4 uPreRotation;
uniform mat4 uPostRotation;
uniform mat4 uRotMat;
uniform float uWidth;
uniform float uHeight;
uniform float uBlendAngle;
uniform float uCircleRadius;
uniform float uCenterX;
uniform float uCenterY;

float alphaNormalized(float t)
{
    float lamda = 5.2;
    float gamma = 1.0/2.2;
    if(t <= 0.5) {
        t = 0.5 * pow(2.0 * t,lamda);
    } else {
        t = 1.0 - 0.5 * pow(2.0 * (1.0 - t),lamda);
    }
    return t;
}

void main() {

    float pi = 3.141592653589793;
    float xi = vPosition.x/uWidth + 0.5;
    float yi = vPosition.y/uHeight + 0.5;

    float phi = pi * yi;
    float theta = (1.0 - xi) * 2.0 * pi;

    float x = sin(phi) * cos(theta);
    float y = sin(phi) * sin(theta);
    float z = -cos(phi);

    vec4 pos = uPreRotation * vec4(x,y,z,1.0);
    pos = uPostRotation * pos;
    pos = uRotMat * pos;
    x = pos.x;
    y = pos.y;
    z = pos.z;


    phi = atan(sqrt(y * y + x * x),z);
	theta = atan(y, x);

    float u = uCircleRadius * cos(theta) + uCenterX;
    float v = uCircleRadius * sin(theta) + uCenterY;

    float angle = phi / pi * 180.0;
    angle = (uBlendAngle/2.0 + 90.0) - angle;

    float t = angle/uBlendAngle;
    t = clamp(t,0.0,1.0);
    t = alphaNormalized(t);
    float alpha1 = t;

    vec4 color1 = texture2D(uTexture,vec2(u,v));
    vec4 color2 = texture2D(uTexture,vTextureCoord);
    gl_FragColor = color1 * alpha1 + (1.0 - alpha1) * color2;
    gl_FragColor.a = 1.0;

}